use_init_root_theme

Function use_init_root_theme 

pub fn use_init_root_theme(theme_cb: impl FnOnce() -> Theme) -> State<Theme>
Provides a custom Theme at the root scope. If a Theme context already exists at the root, it reuses it instead of creating a new one.